SystemOrganization addCategory: #Matcher!
SystemOrganization addCategory: #'Matcher-Test'!

TestCase subclass: #MatcherTest
	instanceVariableNames: 'techTicketApp entrepreneurMatchApp'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher-Test'!

!MatcherTest methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 11:18'!
setUp
	| locColl skillColl |
	techTicketApp := TechTicketApp default.
	entrepreneurMatchApp := EntrepreneurMatchApp default.
	locColl := OrderedCollection new.
	locColl add: (techTicketApp getLocationByName: 'New York City').
	
	skillColl := OrderedCollection new.
	skillColl add: (techTicketApp getSkillByName: 'Computer Repair').

	techTicketApp addTech: (Tech withSkillsCollection: skillColl locationCollection: locColl firstName: 'Test' lastName: 'Techer' address: '1 Tech Way' city: 'Tech City' state: 'NY' zip: '19191' phone: '5555551212'  certificationsCollection: #(ccna microsoft) asOrderedCollection).
! !

!MatcherTest methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 11:24'!
testEntrepreneurCreation

| skillColl locColl traitsColl entrepreneur daysAvailable |
skillColl := OrderedCollection new.
locColl := OrderedCollection new.
traitsColl := OrderedCollection new.
daysAvailable := #(monday wednesday friday) asOrderedCollection.

"changing something.. trying to commit..."

entrepreneur := Entrepreneur withSkillsCollection: skillColl locationCollection: locColl firstName: 'Test' lastName: 'Techer' address: '1 Tech Way' city: 'Tech City' state: 'PA' zip: '19191' phone: '5555551212' traits: traitsColl daysAvailable: daysAvailable.

traitsColl add:#fun.
skillColl add:#java.
locColl add:#miami.

self assert: 'Test Techer'  = entrepreneur fullName.
self assert: '1 Tech Way, Tech City, PA 19191'  = entrepreneur fullAddress.
self assert: true = (entrepreneur hasTrait: #fun).
self assert: true = (entrepreneur hasSkill: #java).
self assert: true = (entrepreneur hasLocation: #miami).! !

!MatcherTest methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 13:47'!
testEntrepreneurMatchApp
|skillColl locColl traitsColl entrepreneurOne entrepreneurTwo daysAvailable countBeforeAdding |

skillColl := OrderedCollection new.
locColl := OrderedCollection new.
traitsColl := OrderedCollection new.
daysAvailable := #(monday wednesday friday) asOrderedCollection.

entrepreneurOne := Entrepreneur withSkillsCollection: skillColl locationCollection: locColl firstName: 'John' lastName: 'Rodriguez' address: '123 Mainstreet' city: 'Sunrise' state: 'FL' zip: '33326' phone: '3063933939' traits: traitsColl daysAvailable: daysAvailable.

entrepreneurTwo := Entrepreneur withSkillsCollection: skillColl locationCollection: locColl firstName: 'Pepe' lastName: 'Smith' address: '1 Tech Way' city: 'Tech City' state: 'PA' zip: '19191' phone: '5555551212' traits: traitsColl daysAvailable: daysAvailable.

countBeforeAdding:= entrepreneurMatchApp entrepreneurCount.

entrepreneurMatchApp addEntrepreneur: entrepreneurOne.
entrepreneurMatchApp addEntrepreneur: entrepreneurTwo.
self assert:  (entrepreneurMatchApp entrepreneurCount) = (countBeforeAdding+2).! !

!MatcherTest methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 15:10'!
testMatchTicketWithTech
| skillColl locColl addedTicketNum newTicket |

skillColl := OrderedCollection new.
locColl := OrderedCollection new.

skillColl add: (MatcherSkill withName: 'Testing' level: 2 description: 'This is a level 2 of 10 skill').
skillColl add: (techTicketApp getSkillByName: 'Computer Repair').
locColl add: (MatcherLocation newWithName: 'Test City' address: '1 Test Street' city: 'Test City' state: 'FL' additionalInfo: 'A place to test').

newTicket := Ticket newWithDescription: 'Test Ticket' priority: 1 dueBy: (Date today) locations: locColl reqSkillsCollection: skillColl createdBy: (MatcherUser fullName: 'Pepe Smith').

addedTicketNum := techTicketApp addTicket: (newTicket).

techTicketApp findTechMatchForTicket: newTicket.! !

!MatcherTest methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 13:39'!
testMatchingScore

| skillColl locColl traitsColl worker daysAvailable |
skillColl := OrderedCollection new.
locColl := OrderedCollection new.
traitsColl := OrderedCollection new.
daysAvailable := #(monday wednesday friday) asOrderedCollection.

worker := Entrepreneur withSkillsCollection: skillColl locationCollection: locColl firstName: 'Test' lastName: 'Techer' address: '1 Tech Way' city: 'Tech City' state: 'PA' zip: '19191' phone: '5555551212' traits: traitsColl daysAvailable: daysAvailable.

self assert: 100 = (worker isAvailableAt: #(wednesday friday)) getScore.
self assert: 50 = (worker isAvailableAt: #(thursday friday)) getScore.
self assert: 100/3 = (worker isAvailableAt: #(sunday thursday friday)) getScore.
self assert: 0 = (worker isAvailableAt: #(saturday)) getScore.

self assert: (worker isAvailableAt: #(wednesday friday)) isFullMatch.
self deny: (worker isAvailableAt: #(thursday friday)) isFullMatch.
self deny: (worker isAvailableAt: #(thursday friday)) isFullMatch.! !

!MatcherTest methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 14:21'!
testPersonCreation

| skillColl locColl person|
skillColl := OrderedCollection new.
locColl := OrderedCollection new.

person := MatcherResource withSkillsCollection: skillColl locationCollection: locColl firstName: 'Test' lastName: 'Techer' address: '1 Tech Way' city: 'Tech City' state: 'PA' zip: '19191' phone: '5555551212'.

self assert: 'Test Techer'  = person fullName.
self assert: '1 Tech Way, Tech City, PA 19191'  = person fullAddress.! !

!MatcherTest methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 14:15'!
testTechCreation
| skillColl locColl certColl tech |

skillColl := OrderedCollection new.
locColl := OrderedCollection new.
certColl := #(ccna microsoft) asOrderedCollection.

skillColl add: (MatcherSkill withName: 'Testing' level: 2 description: 'This is a level 2 of 10 skill').
locColl add: (MatcherLocation newWithName: 'Test City' address: '1 Test Street' city: 'Test City' state: 'FL' additionalInfo: 'A place to test').

tech := (Tech withSkillsCollection: skillColl locationCollection: locColl firstName: 'Test' lastName: 'Techer' address: '1 Tech Way' city: 'Tech City' state: 'PA' zip: '19191' phone: '5555551212'  certificationsCollection: certColl).

techTicketApp addTech: tech.

self assert: true = (tech hasCertification: #ccna).! !

!MatcherTest methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 14:35'!
testTicketCreation
| skillColl locColl certColl tech addedTicketNum newTicket |

skillColl := OrderedCollection new.
locColl := OrderedCollection new.

skillColl add: (MatcherSkill withName: 'Testing' level: 2 description: 'This is a level 2 of 10 skill').
skillColl add: (techTicketApp getSkillByName: 'Computer Repair').
locColl add: (MatcherLocation newWithName: 'Test City' address: '1 Test Street' city: 'Test City' state: 'FL' additionalInfo: 'A place to test').

newTicket := Ticket newWithDescription: 'Test Ticket' priority: 1 dueBy: (Date today) locations: locColl reqSkillsCollection: skillColl createdBy: (MatcherUser fullName: 'Pepe Smith').

addedTicketNum := techTicketApp addTicket: (newTicket).

"self assert: (techTicketApp nextTicketId) = ((techTicketApp ticketCount)+1).
self assert: addedTicketNum = ((techTicketApp nextTicketId)-1).
self assert: (((techTicketApp getTicketById: addedTicketNum) status) getName) = 'Open'."! !

Object subclass: #Dimensions
	instanceVariableNames: 'orderedCollection'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

Dimensions subclass: #Certifications
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

!Certifications methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/1/2013 00:16'!
label
	^'Certifications'! !

Dimensions subclass: #DaysAvailable
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

!DaysAvailable methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/1/2013 00:18'!
label
	^'Days Available'! !

!Dimensions class methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 14:14'!
withCollection: aCollection
	^self new withCollection: aCollection! !

!Dimensions methodsFor: 'private' stamp: 'HectorGonzalez 4/8/2013 14:13'!
dimensionIncludes: aCriteria
^orderedCollection includes: aCriteria! !

!Dimensions methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 14:13'!
getMatchScore: theseCriterias
|totalScore setSize setMatch|

(orderedCollection hasEqualElements:  theseCriterias) 
	ifTrue: [^MatcherScore newWithScore: 100].

setSize := theseCriterias size.
setMatch := 0.

theseCriterias do: [ :criteria | 
	(orderedCollection includes: criteria) 
		ifFalse: [
			
			setMatch := setMatch + 1.
			
			]. 
		].
totalScore := ((setSize - setMatch)*100)/setSize.
	
^MatcherScore newWithScore: totalScore
! !

!Dimensions methodsFor: 'testing' stamp: 'HectorGonzalez 4/8/2013 14:13'!
hasA: aCriteria
^self dimensionIncludes: aCriteria! !

!Dimensions methodsFor: 'testing' stamp: 'HectorGonzalez 4/8/2013 14:13'!
hasAll: theseCriterias
theseCriterias do: [ :criteria | 
	(orderedCollection includes: criteria) ifFalse: [^false]. ].
^true
! !

!Dimensions methodsFor: 'adding' stamp: 'HectorGonzalez 4/8/2013 14:13'!
withCollection: aCollection
orderedCollection := aCollection! !

Dimensions subclass: #Locations
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

!Locations methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/1/2013 00:16'!
label
	^'Locations'! !

Dimensions subclass: #Skills
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

!Skills methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/1/2013 00:15'!
label
	^'Skills'! !

Dimensions subclass: #Traits
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

!Traits methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/1/2013 00:17'!
label
	^'Traits'! !

Object subclass: #MatcherHistorical
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

!MatcherHistorical methodsFor: 'as yet unclassified' stamp: 'Mattf 4/7/2013 21:58'!
README
"this is a purely a placeholder so I don't forget the idea (if we have time) of adding in historical changes to matcher items like tickets or projects"! !

Object subclass: #MatcherHours
	instanceVariableNames: 'beginAvailable endAvailable onCallBegin onCallEnd'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

!MatcherHours methodsFor: 'as yet unclassified' stamp: 'MattF 3/31/2013 12:35'!
withBeginTime: aBeginTime endTime: anEndTime

beginAvailable := aBeginTime .
endAvailable := anEndTime .
onCallBegin := Time midnight.
onCallEnd := Time midnight.! !

!MatcherHours methodsFor: 'as yet unclassified' stamp: 'MattF 3/31/2013 12:35'!
withBeginTime: aBeginTime endTime: anEndTime onCallBeginTime: anOnCallBeginTime onCallEndTime: anOnCallEndTime

beginAvailable := aBeginTime .
endAvailable := anEndTime .
onCallBegin := anOnCallBeginTime.
onCallEnd := anOnCallEndTime.! !

Object subclass: #MatcherItem
	instanceVariableNames: 'name description'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

MatcherItem subclass: #MatcherCertification
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

!MatcherItem methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 14:04'!
getDescription
^description! !

!MatcherItem methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 14:04'!
getName
^name! !

!MatcherItem methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 14:10'!
withName: aName andDescription:aDescription
name:=aName.
description:=aDescription.! !

MatcherItem subclass: #MatcherLocation
	instanceVariableNames: 'address city state additionalInfo'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

!MatcherLocation class methodsFor: 'as yet unclassified' stamp: 'MattF 3/31/2013 01:02'!
empty

^ (MatcherLocation new) newWithName: 'Unknown' address: '' city: '' state: '' additionalInfo: 'Location has not been set'! !

!MatcherLocation class methodsFor: 'as yet unclassified' stamp: 'MattF 3/31/2013 13:04'!
newWithName: strName address: strAddress city: strCity state: strState additionalInfo: strAdditionalInfo

^ self new newWithName: strName address: strAddress city: strCity state: strState additionalInfo: strAdditionalInfo.! !

!MatcherLocation methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 14:18'!
newWithName: aName address: strAddress city: strCity state: strState additionalInfo: strAdditionalInfo
address := strAddress.
city := strCity.
state := strState.
additionalInfo := strAdditionalInfo.

super withName:aName andDescription:''.! !

!MatcherLocation methodsFor: 'as yet unclassified' stamp: 'Mattf 4/7/2013 22:29'!
strName
	^ strName.! !

MatcherItem subclass: #MatcherSkill
	instanceVariableNames: 'level'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

!MatcherSkill class methodsFor: 'as yet unclassified' stamp: 'Mattf 4/7/2013 22:32'!
withName: strName level: numLevel description: strDesc

^ self new withName: strName level: numLevel description: strDesc.! !

!MatcherSkill methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 15:13'!
= aMatcherSkill
	(self skillName = aMatcherSkill getName) ifTrue: [^ true].
	^ false.! !

!MatcherSkill methodsFor: 'as yet unclassified' stamp: 'Mattf 4/7/2013 22:36'!
skillName
	^ skillName! !

!MatcherSkill methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 14:17'!
withName: aName level: numLevel description: aDescription
level := numLevel .
super withName:aName andDescription: aDescription.! !

MatcherItem subclass: #MatcherStatus
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

!MatcherStatus class methodsFor: 'as yet unclassified' stamp: 'Mattf 4/7/2013 20:59'!
newWithName: aName
	^ self new newWithName: aName.! !

!MatcherStatus methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 14:19'!
newWithName: aName
	"I called this strName because name was overriding some base method in Object, which didn't seem right to do"
super withName:aName andDescription: ''.! !

Object subclass: #MatcherMainApp
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

MatcherMainApp class
	instanceVariableNames: 'skillsArray issueArray personArray'!

MatcherMainApp class
	instanceVariableNames: 'skillsArray issueArray personArray'!

MatcherMainApp subclass: #EntrepreneurMatchApp
	instanceVariableNames: 'entrepreneurCollection'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

EntrepreneurMatchApp class
	instanceVariableNames: 'soleInstance'!

EntrepreneurMatchApp class
	instanceVariableNames: 'soleInstance'!

!EntrepreneurMatchApp class methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 13:42'!
default
	(soleInstance isNil) ifTrue: [soleInstance := super new initialize].
	^ soleInstance.! !

!EntrepreneurMatchApp class methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 11:34'!
new
	self error: 'This is a singleton, use default'! !

!EntrepreneurMatchApp methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 11:53'!
addEntrepreneur: anEntrepreneur
entrepreneurCollection add: anEntrepreneur.! !

!EntrepreneurMatchApp methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 11:51'!
entrepreneurCount
	^entrepreneurCollection size! !

!EntrepreneurMatchApp methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 11:52'!
initialize 
entrepreneurCollection := OrderedCollection new.
super initialize.! !

MatcherMainApp subclass: #TechTicketApp
	instanceVariableNames: 'ticketCollection locationCollection techCollection skillCollection'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

TechTicketApp class
	instanceVariableNames: 'soleInstance'!

TechTicketApp class
	instanceVariableNames: 'soleInstance'!

!TechTicketApp class methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 11:31'!
default
	(soleInstance isNil) ifTrue: [soleInstance := super new initialize].
	^ soleInstance.! !

!TechTicketApp class methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 11:34'!
new
	self error: 'This is a singleton, use default'! !

!TechTicketApp methodsFor: 'as yet unclassified' stamp: 'Mattf 4/7/2013 21:51'!
addLocation: aTechLocation
	locationCollection add: aTechLocation.! !

!TechTicketApp methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 11:16'!
addTech: aTech

techCollection add: aTech.! !

!TechTicketApp methodsFor: 'as yet unclassified' stamp: 'Mattf 4/7/2013 21:21'!
addTicket: aTicket
	ticketCollection add: aTicket.
	^ aTicket id. "Returning the ID of the ticket we added makes some sense here, for other applications to not have to take 2 steps, and is the best reference point if they need other info"! !

!TechTicketApp methodsFor: 'as yet unclassified' stamp: 'Mattf 4/7/2013 22:18'!
bestTechMatchesFor: aTicket
	"Provides a dictionary of scores, with techs as keys for a given issue"
	| matchesDict |
	matchesDict  := Dictionary new.
	techCollection do: [:techEle | matchesDict at: techEle put: (aTicket matchScore: techEle) ].
	
	^ matchesDict.
	! !

!TechTicketApp methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 15:10'!
findTechMatchForTicket: aTicket
	"Provides a dictionary of scores, with techs as keys for a given issue"
	| matchesDict |
	matchesDict  := Dictionary new.
	techCollection do: [:techEle | matchesDict at: techEle put: (aTicket matchScore: techEle) ].
	
	^ matchesDict.
	! !

!TechTicketApp methodsFor: 'as yet unclassified' stamp: 'Mattf 4/7/2013 22:36'!
getLocationByName: aName
	locationCollection do: [:ele | (ele strName = aName) ifTrue: [^ ele]].
	^ nil.! !

!TechTicketApp methodsFor: 'as yet unclassified' stamp: 'Mattf 4/7/2013 22:36'!
getSkillByName: aName
	skillCollection do: [:ele | (ele skillName = aName) ifTrue: [^ ele]].
	^ nil.! !

!TechTicketApp methodsFor: 'as yet unclassified' stamp: 'Mattf 4/7/2013 21:24'!
getTicketById: anIdNumber
	"Returns a ticket based on it's ID number"
	| aTicket |
	^ ticketCollection do: [:ele | ((ele id) = anIdNumber) ifTrue: [ ^ ele ] ].! !

!TechTicketApp methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 14:17'!
initialize 
"Start up the main app object with some default values for logical items and initialize the others to a base collection"

ticketCollection := OrderedCollection new.

locationCollection := OrderedCollection new.
"there should be some default locations I would think...user can take them out if not needed?"
locationCollection add: (MatcherLocation newWithName: 'New York City' address: '1 Main St.' city: 'New York' state: 'NY' additionalInfo: 'Main NY Office').
locationCollection add: (MatcherLocation newWithName: 'Washington DC' address: '1600 Pennsylvania Ave.' city: 'Washington' state: 'DC' additionalInfo: 'Main DC Office').
locationCollection add: (MatcherLocation newWithName: 'San Francisco' address: '100 Lombard St.' city: 'San Francisco' state: 'CA' additionalInfo: 'Main SF Office').

"adding in some base skills... no point in adding a level, that should be user set for either the ticket to assign it to or the tech to assign it to... this will just allow us a base list to show"
skillCollection := OrderedCollection new.
skillCollection add: (MatcherSkill withName: 'Computer Repair' level: 0 description: 'Ability to fix computers').
skillCollection add: (MatcherSkill withName: 'Electrical Repair' level: 0 description: 'Electrical Certification').

techCollection := OrderedCollection new.
super initialize .! !

!TechTicketApp methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 14:51'!
nextTicketId
"Provides the next ticket id from the system, so we don't ever re-use an ID"
	| newTicketNum |
	newTicketNum := 1.
	(ticketCollection size = 0) ifTrue:[^newTicketNum].
	ticketCollection do: [:element | 
		((element = nil) or: (element id) = nil) ifFalse: [ 
			
							((element id) >= newTicketNum)
							 ifTrue: [newTicketNum := (element id) +1]
			
								].
	].
	^ newTicketNum.! !

!TechTicketApp methodsFor: 'as yet unclassified' stamp: 'Mattf 4/7/2013 20:48'!
privateRemoveAllTickets
	"this is a helper method for me to clear a system of tickets when needed for testing, though i guess it could be used as a user function, but probably too potentially hurtful"
	ticketCollection := OrderedCollection new.! !

!TechTicketApp methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/7/2013 18:02'!
ticketCount
	^ticketCollection size
! !

Object subclass: #MatcherResource
	instanceVariableNames: 'id skills locations fname lname address city state zip phone description'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

MatcherResource subclass: #Cat
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

MatcherResource subclass: #Entrepreneur
	instanceVariableNames: 'traits daysAvailable'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

!Entrepreneur class methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/1/2013 00:09'!
withSkillsCollection: skillsArr locationCollection: locationArr firstName: strFName lastName: strLName address: strAddress city: strCity state: strState zip: strZip phone: strPhone traits: traitsArr daysAvailable: aSetOfDaysAvailable

^ self new withSkillsCollection: skillsArr locationCollection: locationArr firstName: strFName lastName: strLName address: strAddress city: strCity state: strState zip: strZip phone: strPhone traits: traitsArr daysAvailable: aSetOfDaysAvailable.

! !

!Entrepreneur methodsFor: 'testing' stamp: 'HectorGonzalez 3/31/2013 23:49'!
hasTrait: aTrait
	^(traits hasA: aTrait).! !

!Entrepreneur methodsFor: 'testing' stamp: 'HectorGonzalez 4/8/2013 10:59'!
isAvailableAt: theseDays
	^(daysAvailable getMatchScore:  theseDays).! !

!Entrepreneur methodsFor: 'initialize-release' stamp: 'HectorGonzalez 4/1/2013 00:19'!
withSkillsCollection: skillsArr locationCollection: locationArr firstName: strFName lastName: strLName address: strAddress city: strCity state: strState zip: strZip phone: strPhone traits: traitsArr daysAvailable: aSetOfDaysAvailable

super 	withSkillsCollection: skillsArr 
			locationCollection: locationArr 
			firstName: strFName 
			lastName: strLName 
			address: strAddress 
			city: strCity 
			state: strState 
			zip: strZip 
			phone: strPhone.

traits := Traits withCollection: traitsArr.
daysAvailable := DaysAvailable withCollection: aSetOfDaysAvailable.! !

!MatcherResource class methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 3/31/2013 20:50'!
withSkillsCollection: skillsArr locationCollection: locationArr firstName: strFName lastName: strLName address: strAddress city: strCity state: strState zip: strZip phone: strPhone

^ self new withSkillsCollection: skillsArr locationCollection: locationArr firstName: strFName lastName: strLName address: strAddress city: strCity state: strState zip: strZip phone: strPhone.! !

!MatcherResource methodsFor: 'accessing' stamp: 'HectorGonzalez 3/31/2013 20:57'!
fullAddress
	^ (address, ', ', city, ', ', state, ' ', zip)! !

!MatcherResource methodsFor: 'accessing' stamp: 'HectorGonzalez 3/31/2013 20:48'!
fullName
  ^(fname, ' ', lname)! !

!MatcherResource methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 3/31/2013 23:46'!
hasLocation: aLocation
	^(locations hasA: aLocation).! !

!MatcherResource methodsFor: 'testing' stamp: 'HectorGonzalez 3/31/2013 23:41'!
hasSkill: aSkill
	^(skills hasA: aSkill).! !

!MatcherResource methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 14:23'!
id
	^ id.! !

!MatcherResource methodsFor: 'initialize-release' stamp: 'HectorGonzalez 4/1/2013 00:19'!
withSkillsCollection:  skillsArr locationCollection:  locationArr firstName: strFName lastName: strLName address: strAddress city: strCity state: strState zip: strZip phone: strPhone
	
fname := strFName.
lname := strLName.
address := strAddress.
city := strCity.
state := strState.
zip := strZip.
phone := strPhone.

skills := Skills withCollection: skillsArr.
locations := Locations withCollection: locationArr.! !

MatcherResource subclass: #Tech
	instanceVariableNames: 'certifications currentLocation weeklyScheduleDict exceptionScheduleDict ticketAssignmentsCollection'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

!Tech class methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 3/31/2013 23:53'!
withSkillsCollection: skillsArr locationCollection: locationArr firstName: strFName lastName: strLName address: strAddress city: strCity state: strState zip: strZip phone: strPhone certificationsCollection: certificationsArr

^ self new withSkillsCollection: skillsArr locationCollection: locationArr firstName: strFName lastName: strLName address: strAddress city: strCity state: strState zip: strZip phone: strPhone certificationsCollection: certificationsArr.! !

!Tech methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/1/2013 00:00'!
hasCertification: aCertification
	^(certifications hasA: aCertification).! !

!Tech methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/1/2013 00:19'!
withSkillsCollection: skillsArr locationCollection: locationArr firstName: strFName lastName: strLName address: strAddress city: strCity state: strState zip: strZip phone: strPhone certificationsCollection: certificationsArr

super 	withSkillsCollection: skillsArr 
			locationCollection: locationArr 
			firstName: strFName 
			lastName: strLName 
			address: strAddress 
			city: strCity 
			state: strState 
			zip: strZip 
			phone: strPhone.

currentLocation := nil.
weeklyScheduleDict := Dictionary new.
weeklyScheduleDict at: #sunday put: OrderedCollection new. "new object for times in these days??"
weeklyScheduleDict at: #monday put: OrderedCollection new.
weeklyScheduleDict at: #tuesday put: OrderedCollection new.
weeklyScheduleDict at: #wednesday put: OrderedCollection new.
weeklyScheduleDict at: #thursday put: OrderedCollection new.
weeklyScheduleDict at: #friday put: OrderedCollection new.
weeklyScheduleDict at: #saturday put: OrderedCollection new.
exceptionScheduleDict := Dictionary new. "put hours in for symbol which is the date, maybe a time object holder??"
ticketAssignmentsCollection := OrderedCollection new.

certifications := Certifications withCollection: certificationsArr.! !

MatcherResource subclass: #Ticket
	instanceVariableNames: 'priority dueByTime status creator assignedPersonsCollection'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

!Ticket class methodsFor: 'as yet unclassified' stamp: 'Mattf 4/5/2013 23:00'!
newWithDescription: desc priority: priorityNum dueBy: dueByDate locations: locColl reqSkillsCollection: reqSkillsColl createdBy: user

^ self new newWithDescription: desc priority: priorityNum dueBy: dueByDate locations: locColl reqSkillsCollection: reqSkillsColl createdBy: user

! !

!Ticket methodsFor: 'as yet unclassified' stamp: 'Mattf 4/5/2013 22:58'!
assignTech: aTech
	assignedPersonsCollection add: aTech.! !

!Ticket methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 15:08'!
getMatchScore: theseCriterias
|totalScore setSize setMatch|

(skills hasEqualElements:  theseCriterias) 
	ifTrue: [^MatcherScore newWithScore: 100].

setSize := theseCriterias size.
setMatch := 0.

theseCriterias do: [ :criteria | 
	(skills includes: criteria) 
		ifFalse: [
			
			setMatch := setMatch + 1.
			
			]. 
		].
totalScore := ((setSize - setMatch)*100)/setSize.
	
^MatcherScore newWithScore: totalScore
! !

!Ticket methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 15:12'!
matchScore: aTech
"accepts a ticket object and a tech object to provide a score or true/false for how well they match up"
"not sure if this should be in its own class for a good pattern use somewhere"
| skillScore locScore tempScore tempCount |
tempScore := 0.
tempCount := (skills) size.
skills do: [:ele | (aTech hasSkill: ele) ifTrue: [tempScore := tempScore + 1]]. 
tempScore :=  tempScore / tempCount * 100. "0-100 score for skill matches"
skillScore := tempScore.

tempCount := (locations) size.
locations do: [:ele | (aTech hasLocation: ele) ifTrue: [tempScore := tempScore + 1]]. 
tempScore :=  tempScore / tempCount * 100. "0-100 score for loc matches"
locScore := tempScore.

"here we could put weights for items maybe the user could end up specifying??  I will use 75% skill 25% location"
tempScore := (skillScore * 0.75) + (locScore * 0.25).

^ MatcherScore newWithScore: tempScore.! !

!Ticket methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 14:31'!
newWithDescription: desc priority: priorityNum dueBy: dueByDate locations: locColl reqSkillsCollection: reqSkillsColl createdBy: user

id := TechTicketApp default nextTicketId.
description := desc.
priority := priorityNum.
dueByTime := dueByDate.
status := MatcherStatus newWithName: 'Open'. 
creator := user.
assignedPersonsCollection := OrderedCollection new.
skills := locColl.
locations := reqSkillsColl.

! !

!Ticket methodsFor: 'as yet unclassified' stamp: 'Mattf 4/5/2013 22:58'!
removeTech: aTech
	assignedPersonsCollection remove: aTech.! !

!Ticket methodsFor: 'as yet unclassified' stamp: 'Mattf 4/7/2013 21:00'!
status
	^ status! !

Object subclass: #MatcherScore
	instanceVariableNames: 'score fullMatch'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

MatcherScore class
	instanceVariableNames: 'scaleDictionary'!

MatcherScore class
	instanceVariableNames: 'scaleDictionary'!

!MatcherScore class methodsFor: 'as yet unclassified' stamp: 'Mattf 4/7/2013 22:16'!
newWithScore: aNumber
	^ self new newWithScore: aNumber.! !

!MatcherScore methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 10:43'!
getScore
	^score! !

!MatcherScore methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 13:33'!
isFullMatch
	^(score = 100).! !

!MatcherScore methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 13:32'!
newWithScore: aNumber
	score := aNumber.! !

Object subclass: #MatcherUser
	instanceVariableNames: 'fullName'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

!MatcherUser class methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/7/2013 17:48'!
fullName: aFullName
	^self new fullName: aFullName! !

!MatcherUser methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/7/2013 17:49'!
fullName: aFullName
fullName:=aFullName! !
